/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: CmiComponent.java 2164 2007-12-11 21:34:34Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.component.cmi;

import org.ow2.easybeans.component.api.EZBComponent;
import org.ow2.easybeans.component.api.EZBComponentException;
import org.ow2.easybeans.server.ServerConfig;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * Component providing a support of CMI.
 * @author WEI Zhouyue & ZHU Ning
 */
public class CmiComponent implements EZBComponent {

    /**
     * Logger.
     */
    private Log logger = LogFactory.getLog(CmiComponent.class);

    /**
     * Configuration of the embedded instance.
     */
    private ServerConfig config;

    /**
     * Init method.<br/>
     * This method is called before the start method.
     * @throws EZBComponentException if the initialization has failed.
     */
    public void init() throws EZBComponentException {
        // Do nothing
    }

    /**
     * Start method.<br/>
     * This method is called after the init method.
     * @throws EZBComponentException if the start has failed.
     */
    public void start() throws EZBComponentException {
        // Add the callback
        config.addExtensionFactory(new CmiConfigurationExtension());
        logger.debug("The CMI configuration extension has been added.");
    }

    /**
     * Stop method.<br/>
     * This method is called when component needs to be stopped.
     * @throws EZBComponentException if the stop is failing.
     */
    public void stop() throws EZBComponentException {
        // Do nothing
    }

    /**
     * Return the configuration of the embedded instance.
     * @return the configuration of the embedded instance
     */
    public ServerConfig getServerConfig() {
        return config;
    }

    /**
     * Set the configuration of the embedded instance.
     * @param config the configuration of the embedded instance
     */
    public void setServerConfig(final ServerConfig config) {
        this.config = config;
    }


}
