/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JNDIBindingFactory.java 2557 2008-03-04 18:12:05Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.proxy.binding;

import javax.naming.InitialContext;
import javax.naming.NamingException;

import org.ow2.easybeans.api.binding.BindingException;
import org.ow2.easybeans.api.binding.EZBBindingFactory;
import org.ow2.easybeans.api.binding.EZBRef;

/**
 * Binding of the reference in the JNDI/Registry.
 * @author Florent BENOIT
 */
public class JNDIBindingFactory implements EZBBindingFactory {

    /**
     * Binds a reference with the given JNDI name and the given referenceable
     * object.
     * @param ref the EasyBeans reference object
     * @throws BindingException if the bind fails.
     */
    public void bind(final EZBRef ref) throws BindingException {
        try {
            new InitialContext().rebind(ref.getJNDIName(), ref);
        } catch (NamingException e) {
            throw new BindingException("Cannot bind the object with JNDI name '" + ref.getJNDIName() + "' and reference '" + ref
                    + "'.", e);
        }
    }

    /**
     * Unbinds an object with the given JNDI name.
     * @param ref the EasyBeans reference object
     * @throws BindingException if the bind fails.
     */
    public void unbind(final EZBRef ref) throws BindingException {
        try {
            new InitialContext().unbind(ref.getJNDIName());
        } catch (NamingException e) {
            throw new BindingException("Cannot unbind the object with JNDI name '" + ref.getJNDIName() + "'.", e);
        }
    }

}
