/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id:WarAnnotationDeploymentAnalyzer.java 2059 2007-11-22 17:22:33Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.analyzer;

import java.util.List;

import org.ow2.easybeans.deployment.annotations.analyzer.configurator.metadata.war.WarArchiveMetadataConfigurator;
import org.ow2.easybeans.deployment.metadata.war.WarArchiveMetadata;
import org.ow2.util.deployment.annotations.analyzer.AnalyzerException;
import org.ow2.util.deployment.annotations.analyzer.ArchiveScanner;
import org.ow2.util.ee.deploy.api.archive.IArchive;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * This class fill metadata for Servlet classes.
 * @author Florent Benoit
 */
public class WarAnnotationDeploymentAnalyzer {

    /**
     * Logger.
     */
    private static Log logger = LogFactory.getLog(WarAnnotationDeploymentAnalyzer.class);

    /**
     * Metadata representing the parsed war file.
     */
    private WarArchiveMetadataConfigurator warArchiveMetadataConfigurator = null;

    /**
     * The scanner.
     */
    private ArchiveScanner archiveScanner;

    /**
     * Constructor.<br>
     * Archive which will be used when analyzing.
     * @param archive the archive to analyze.
     * @param classLoader the classloader used to read the classes.
     */
    public WarAnnotationDeploymentAnalyzer(final IArchive archive, final ClassLoader classLoader) {
        archiveScanner = new ArchiveScanner(archive);
        warArchiveMetadataConfigurator = new WarArchiveMetadataConfigurator();
        archiveScanner.addArchiveConfigurator(warArchiveMetadataConfigurator);
    }

    /**
     * Analyzes the given set of classes and fill metadata struct.
     * @param classNames the class names to analyze
     * @throws AnalyzerException if analyze of archive fails
     */
    public void analyze(final List<String> classNames) throws AnalyzerException {
        //TODO: Analyze super classes

        // Analyze the set of given classes

        archiveScanner.scanCollection(classNames);
        archiveScanner.endScan();
    }

    /**
     * @return struct (metadata) filled by this analyzer
     */
    public WarArchiveMetadata getWarArchiveMetadata() {
        return warArchiveMetadataConfigurator.getWarArchiveMetadata();
    }
}
