package org.ow2.easybeans.deployment.annotations.analyzer.configurator.metadata.ejbjar;

import org.ow2.easybeans.deployment.annotations.analyzer.configurator.metadata.CommonClassMetadataConfigurator;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.JavaxAnnotationSecurityPermitAllVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.JavaxAnnotationSecurityRolesAllowedVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.JavaxEjbTransactionAttributeVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.JavaxInterceptorExcludeDefaultInterceptorsVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.JavaxInterceptorInterceptorsVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz.JavaxAnnotationSecurityDeclareRolesVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz.JavaxAnnotationSecurityRunAs;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz.JavaxEjbApplicationExceptionVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz.JavaxEjbLocalHomeVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz.JavaxEjbLocalVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz.JavaxEjbMessageDrivenVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz.JavaxEjbRemoteHomeVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz.JavaxEjbRemoteVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz.JavaxEjbStatefulVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz.JavaxEjbStatelessVisitor;
import org.ow2.easybeans.deployment.annotations.analyzer.visitors.clazz.JavaxEjbTransactionManagementVisitor;
import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarArchiveMetadata;
import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarClassMetadata;
import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarFieldMetadata;
import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarMethodMetadata;
import org.ow2.util.deployment.annotations.analyzer.configurator.FieldConfigurator;
import org.ow2.util.deployment.annotations.analyzer.configurator.MethodConfigurator;
import org.ow2.util.deployment.metadata.structures.JClass;
import org.ow2.util.deployment.metadata.structures.JField;
import org.ow2.util.deployment.metadata.structures.JMethod;
import org.ow2.util.pool.impl.visitor.PoolVisitor;


/**
 * EjbJarClassMetadataConfigurator.
 * @author Gael Lalire
 */
public class EjbJarClassMetadataConfigurator extends
        CommonClassMetadataConfigurator<EjbJarClassMetadata, EjbJarMethodMetadata, EjbJarFieldMetadata> {


    /**
     * annotationParsingDesactived.
     */
    private boolean annotationParsingDesactived;

    /**
     * EjbJarClassMetadataConfigurator.
     * @param jClass signature
     * @param ejbJarArchiveMetadata parent
     * @param annotationParsingDesactived annotationParsingDesactived
     */
    public EjbJarClassMetadataConfigurator(final JClass jClass, final EjbJarArchiveMetadata ejbJarArchiveMetadata,
            final boolean annotationParsingDesactived) {
        super(new EjbJarClassMetadata(jClass, ejbJarArchiveMetadata));
        this.annotationParsingDesactived = annotationParsingDesactived;
        if (!annotationParsingDesactived) {
            registerAnnotationVisitor();
        }
    }

    /**
     * register annotation visitor.
     */
    @Override
    protected void registerAnnotationVisitor() {

        super.registerAnnotationVisitor();

        EjbJarClassMetadata ejbJarClassMetadata = getClassMetadata();

        // add @Local
        getAnnotationVisitors().put(JavaxEjbLocalVisitor.TYPE, new JavaxEjbLocalVisitor(ejbJarClassMetadata));

        // add @Remote
        getAnnotationVisitors().put(JavaxEjbRemoteVisitor.TYPE, new JavaxEjbRemoteVisitor(ejbJarClassMetadata));

        // add @Stateless
        getAnnotationVisitors().put(JavaxEjbStatelessVisitor.TYPE,
                new JavaxEjbStatelessVisitor(ejbJarClassMetadata));

        // add @Stateful
        getAnnotationVisitors().put(JavaxEjbStatefulVisitor.TYPE, new JavaxEjbStatefulVisitor(ejbJarClassMetadata));

        // add @MessageDriven
        getAnnotationVisitors().put(JavaxEjbMessageDrivenVisitor.TYPE, new JavaxEjbMessageDrivenVisitor(
                ejbJarClassMetadata));

        // add @LocalHome
        getAnnotationVisitors().put(JavaxEjbLocalHomeVisitor.TYPE,
                new JavaxEjbLocalHomeVisitor(ejbJarClassMetadata));

        // add @RemoteHome
        getAnnotationVisitors().put(JavaxEjbRemoteHomeVisitor.TYPE, new JavaxEjbRemoteHomeVisitor(
                ejbJarClassMetadata));

        // add @TransactionManagement
        getAnnotationVisitors().put(JavaxEjbTransactionManagementVisitor.TYPE,
                new JavaxEjbTransactionManagementVisitor(ejbJarClassMetadata));

        // add @TransactionAttribute
        getAnnotationVisitors().put(JavaxEjbTransactionAttributeVisitor.TYPE,
                new JavaxEjbTransactionAttributeVisitor<EjbJarClassMetadata>(ejbJarClassMetadata));

        // add @Interceptors
        getAnnotationVisitors().put(JavaxInterceptorInterceptorsVisitor.TYPE,
                new JavaxInterceptorInterceptorsVisitor<EjbJarClassMetadata>(ejbJarClassMetadata));

        // add @ApplicationException
        getAnnotationVisitors().put(JavaxEjbApplicationExceptionVisitor.TYPE, new JavaxEjbApplicationExceptionVisitor(
                ejbJarClassMetadata));

        // add @DeclareRoles
        getAnnotationVisitors().put(JavaxAnnotationSecurityDeclareRolesVisitor.TYPE,
                new JavaxAnnotationSecurityDeclareRolesVisitor(ejbJarClassMetadata));

        // add @RolesAllowed
        getAnnotationVisitors().put(JavaxAnnotationSecurityRolesAllowedVisitor.TYPE,
                new JavaxAnnotationSecurityRolesAllowedVisitor<EjbJarClassMetadata>(ejbJarClassMetadata));

        // add @PermitAll
        getAnnotationVisitors().put(JavaxAnnotationSecurityPermitAllVisitor.TYPE,
                new JavaxAnnotationSecurityPermitAllVisitor<EjbJarClassMetadata>(ejbJarClassMetadata));

        // add @RunAs
        getAnnotationVisitors().put(JavaxAnnotationSecurityRunAs.TYPE,
                new JavaxAnnotationSecurityRunAs(ejbJarClassMetadata));

        // add @ExcludeDefaultInterceptors
        getAnnotationVisitors().put(JavaxInterceptorExcludeDefaultInterceptorsVisitor.TYPE,
                new JavaxInterceptorExcludeDefaultInterceptorsVisitor<EjbJarClassMetadata>(ejbJarClassMetadata));


        // Add @Pool specific annotation
        getAnnotationVisitors().put(PoolVisitor.TYPE, new PoolVisitor(ejbJarClassMetadata));

    }

    /**
     * @param jField signature
     * @return configurator
     */
    @Override
    protected FieldConfigurator createFieldMetadataConfigurator(final JField jField) {
        return new EjbJarFieldMetadataConfigurator(jField, getClassMetadata(), annotationParsingDesactived);
    }

    /**
     * @param jMethod signature
     * @return configurator
     */
    @Override
    protected MethodConfigurator createMethodMetadataConfigurator(final JMethod jMethod) {
        return new EjbJarMethodMetadataConfigurator(jMethod, getClassMetadata(), annotationParsingDesactived);
    }

    /**
     * add class to archive.
     */
    @Override
    public void configurationComplete() {
       EjbJarClassMetadata ejbJarClassMetadata = getClassMetadata();
       ejbJarClassMetadata.getEjbJarArchiveMetadata().addEjbJarClassMetadata(ejbJarClassMetadata);
    }

}
