/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ENCBindingHolder.java 2067 2007-11-27 10:03:12Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.enc;

import java.util.ArrayList;
import java.util.List;

import org.ow2.easybeans.deployment.api.EZBENCBindingHolder;
import org.ow2.easybeans.deployment.api.IBinding;
import org.ow2.easybeans.deployment.api.IJAnnotationResource;
import org.ow2.easybeans.deployment.api.IJavaxPersistenceContext;
import org.ow2.easybeans.deployment.api.IJavaxPersistenceUnit;

/**
 * Class that can manage different kind of binding used in ENC.
 * @author Florent BENOIT
 */
public class ENCBindingHolder implements EZBENCBindingHolder {

    /**
     * List of binding for Persistence context (Entity Manager).
     */
    private List<IBinding<IJavaxPersistenceContext>> persistenceContextBindings = null;

    /**
     * List of binding for Persistence unit (Entity Manager Factory).
     */
    private List<IBinding<IJavaxPersistenceUnit>> persistenceUnitBindings = null;

    /**
     * List of binding for Javax.Annotation.Resources.
     */
    private List<IBinding<IJAnnotationResource>> resourceBindings = null;

    /**
     * Default constructor.
     */
    public ENCBindingHolder() {
        this.persistenceContextBindings = new ArrayList<IBinding<IJavaxPersistenceContext>>();
        this.persistenceUnitBindings = new ArrayList<IBinding<IJavaxPersistenceUnit>>();
        this.resourceBindings = new ArrayList<IBinding<IJAnnotationResource>>();
    }

    /**
     * Add a given persistence context binding.
     * @param binding the given binding.
     */
    public void addPersistenceContextBinding(final IBinding<IJavaxPersistenceContext> binding) {
        this.persistenceContextBindings.add(binding);
    }

    /**
     * @return the list of persistence context bindings.
     */
    public List<IBinding<IJavaxPersistenceContext>> getPersistenceContextBindings() {
        return persistenceContextBindings;
    }

    /**
     * Add a given persistence unit binding.
     * @param binding the given binding.
     */
    public void addPersistenceUnitBinding(final IBinding<IJavaxPersistenceUnit> binding) {
        this.persistenceUnitBindings.add(binding);
    }

    /**
     * @return the list of persistence unit bindings.
     */
    public List<IBinding<IJavaxPersistenceUnit>> getPersistenceUnitBindings() {
        return persistenceUnitBindings;
    }

    /**
     * Add a given resource binding.
     * @param binding the given binding.
     */
    public void addResourceBinding(final IBinding<IJAnnotationResource> binding) {
        this.resourceBindings.add(binding);
    }
    /**
     * @return the list of resource bindings.
     */
    public List<IBinding<IJAnnotationResource>> getResourceBindings() {
        return resourceBindings;
    }


}
