/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id:WarArchiveMetadata.java 2372 2008-02-08 18:18:37Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.metadata.war;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * This class represents the annotation metadata of all classes of a War
 * file. From this class, we can get metadata of all classes.
 * @author Florent Benoit
 */
public class WarArchiveMetadata {

    /**
     * Logger.
     */
    private static Log logger = LogFactory.getLog(WarArchiveMetadata.class);

    /**
     * List of class annotations metadata.
     */
    private Map<String, WarClassMetadata> warClassMetadataMap = null;

    /**
     * Constructor.
     */
    public WarArchiveMetadata() {
        warClassMetadataMap = new HashMap<String, WarClassMetadata>();
    }

    /**
     * Add annotation metadata for a given class.
     * @param warClassMetadata metadata of a class.
     */
    public void addWarClassMetadata(final WarClassMetadata warClassMetadata) {
        String key = warClassMetadata.getJClass().getName();
        // already exists ?
        if (warClassMetadataMap.containsKey(key)) {
            throw new IllegalStateException("addWarClassMetadata : key already exists");
        }
        warClassMetadataMap.put(key, warClassMetadata);
    }


    /**
     * Get class annotation metadata.
     * @param className key of the map of annotations bean.
     * @return Bean annotation metadata of a given name.
     */
    public WarClassMetadata getWarClassMetadata(final String className) {
        return warClassMetadataMap.get(className);
    }

    /**
     * Get collections of bean annotation metadata.
     * @return collections of bean annotation metadata.
     */
    public Collection<WarClassMetadata> getWarClassMetadataCollection() {
        return warClassMetadataMap.values();
    }

}
