/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ContainerTransaction.java 2059 2007-11-22 17:22:33Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.xml.struct;

import java.util.LinkedList;
import java.util.List;

import javax.ejb.TransactionAttributeType;

import org.ow2.easybeans.deployment.xml.struct.common.MethodDD;

/**
 * Defines a contrainer transaction used within an assembly descriptor.
 * @author Florent BENOIT
 */
public class ContainerTransaction {

    /**
     * Name of this element.
     */
    public static final String NAME = "container-transaction";

    /**
     * List of method on which apply this container transaction block.
     */
    private List<MethodDD> methods = null;

    /**
     * Transaction Attribute set by this container transaction.
     */
    private TransactionAttributeType txAttribute = null;


    /**
     * Defines a new Container transaction object.
     */
    public ContainerTransaction() {
        this.methods = new LinkedList<MethodDD>();
    }

    /**
     * Add a new Method.
     * @param method the given method.
     */
    public void addMethod(final MethodDD method) {
        this.methods.add(method);
    }

    /**
     * @return list of methods.
     */
    public List<MethodDD> getMethods() {
        return this.methods;
    }

    /**
     * Sets the transaction attribute for this block.
     * @param txAttribute the given transaction attribute
     */
    public void setTransactionAttribute(final TransactionAttributeType txAttribute) {
        this.txAttribute = txAttribute;
    }

    /**
     * Gets the transaction attribute for this block.
     * @return the transaction attribute
     */
    public TransactionAttributeType getTransactionAttribute() {
        return this.txAttribute;
    }

    /**
     * @return string representation of this module.
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder(ContainerTransaction.class.getSimpleName());
        sb.append("[");
        for (MethodDD method : methods) {
            sb.append(method);
        }
        sb.append(", txAttribute=");
        sb.append(txAttribute);
        sb.append("]");
        return sb.toString();
    }

}
