/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: SLSBSimpleEnvEntryMethodInjection00.java 1970 2007-10-16 11:49:25Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.easybeans.tests.common.ejbs.stateless.containermanaged.simpleentry;

import static org.ow2.easybeans.tests.common.helper.ContextHelper.checkSimpleEntry;

import javax.annotation.Resource;
import javax.ejb.Remote;
import javax.ejb.SessionContext;
import javax.ejb.Stateless;

import org.ow2.easybeans.tests.common.ejbs.base.ItfSimpleEnvEntry;

/**
 * This bean is used to test injection of simple environment entries in set methods.
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
@Stateless(name="SLSBSimpleEnvEntryMethodInjection00")
@Remote(ItfSimpleEnvEntry.class)
public class SLSBSimpleEnvEntryMethodInjection00 implements ItfSimpleEnvEntry {

    /**
     * SessionContext.
     */
    @Resource
    private SessionContext sessionContext;

    /**
     * Property inicialized by an injection.
     */
    private String strInjection;

    /**
     * Property inicialized by an injection.
     */
    private char chrInjection;

    /**
     * Property inicialized by an injection.
     */
    private int intInjection;

    /**
     * Property inicialized by an injection.
     */
    private boolean bolInjection;

    /**
     * Property inicialized by an injection.
     */
    private double dblInjection;

    /**
     * Property inicialized by an injection.
     */
    private byte bteInjection;

    /**
     * Property inicialized by an injection.
     */
    private short shrInjection;

    /**
     * Property inicialized by an injection.
     */
    private long lngInjection;

    /**
     * Property inicialized by an injection.
     */
    private float fltInjection;

    /**
     * The default value must be injected by the container.
     * @param value information value
     */
    @Resource(name = "str00")
    public void setStrInjection(final String value){
        strInjection = value;
    }

    /**
     * The default value must be injected by the container.
     * @param value information value
     */
    @SuppressWarnings("unused")
    @Resource(name = "chr00")
    private void setChrInjection(final char value){
        chrInjection = value;
    }

    /**
     * The default value must be injected by the container.
     * @param value information value
     */
    @Resource(name = "int00")
    protected void setIntInjection(final int value){
        intInjection = value;
    }

    /**
     * The default value must be injected by the container.
     * @param value information value
     */
    @Resource(name = "bol00")
    void setBolInjection(final boolean value){
        bolInjection = value;
    }

    /**
     * The default value must be injected by the container.
     * @param value information value
     */
    @Resource(name = "dbl00")
    public void setDblInjection(final double value){
        dblInjection = value;
    }

    /**
     * The default value must be injected by the container.
     * @param value information value
     */
    @Resource(name = "bte00")
    public void setBteInjection(final byte value){
        bteInjection = value;
    }

    /**
     * The default value must be injected by the container.
     * @param value information value
     */
    @Resource(name = "shr00")
    public void setShrInjection(final short value){
        shrInjection = value;
    }

    /**
     * The default value must be injected by the container.
     * @param value information value
     */
    @Resource(name = "lng00")
    public void setLngInjection(final long value){
        lngInjection = value;
    }

    /**
     * The default value must be injected by the container. The name must be generated by the container: class name/field name.
     * @param value information value
     */
    @Resource
    public void setFltInjection(final float value){
        fltInjection = value;
    }

    /**
     * @see org.ow2.easybeans.tests.common.ejbs.base.ItfSimpleEnvEntry
     */
    public void checkString00() {
        checkSimpleEntry(sessionContext, "str00", strInjection, ENTRY_STRING);
    }

    /**
     * @see org.ow2.easybeans.tests.common.ejbs.base.ItfSimpleEnvEntry
     */
    @SuppressWarnings("boxing")
    public void checkCharacter00() {
        checkSimpleEntry(sessionContext, "chr00", chrInjection, ENTRY_CHARACTER);
    }

    /**
     * @see org.ow2.easybeans.tests.common.ejbs.base.ItfSimpleEnvEntry
     */
    @SuppressWarnings("boxing")
    public void checkInteger00() {
        checkSimpleEntry(sessionContext, "int00", intInjection, ENTRY_INTEGER);
    }

    /**
     * @see org.ow2.easybeans.tests.common.ejbs.base.ItfSimpleEnvEntry
     */
    @SuppressWarnings("boxing")
    public void checkBoolean00() {
        checkSimpleEntry(sessionContext, "bol00", bolInjection, ENTRY_BOOLEAN);
    }

    /**
     * @see org.ow2.easybeans.tests.common.ejbs.base.ItfSimpleEnvEntry
     */
    @SuppressWarnings("boxing")
    public void checkDouble00() {
        checkSimpleEntry(sessionContext, "dbl00", dblInjection, ENTRY_DOUBLE);
    }

    /**
     * @see org.ow2.easybeans.tests.common.ejbs.base.ItfSimpleEnvEntry
     */
    @SuppressWarnings("boxing")
    public void checkByte00() {
        checkSimpleEntry(sessionContext, "bte00", bteInjection, ENTRY_BYTE);
    }

    /**
     * @see org.ow2.easybeans.tests.common.ejbs.base.ItfSimpleEnvEntry
     */
    @SuppressWarnings("boxing")
    public void checkShort00() {
        checkSimpleEntry(sessionContext, "shr00", shrInjection, ENTRY_SHORT);
    }

    /**
     * @see org.ow2.easybeans.tests.common.ejbs.base.ItfSimpleEnvEntry
     */
    @SuppressWarnings("boxing")
    public void checkLong00() {
        checkSimpleEntry(sessionContext, "lng00", lngInjection, ENTRY_LONG);
    }

    /**
     * @see org.ow2.easybeans.tests.common.ejbs.base.ItfSimpleEnvEntry
     */
    @SuppressWarnings("boxing")
    public void checkFloat00() {
        checkSimpleEntry(sessionContext, this.getClass().getName().toString()+"/"+ "fltInjection", fltInjection, ENTRY_FLOAT);
    }
}
